pub struct BundleResponse {Show 13 fields
pub bonded: Option<bool>,
pub bundles: Option<HashMap<String, BundleDetails>>,
pub creator_analysis: Option<CreatorAnalysis>,
pub distributed_amount: Option<i64>,
pub distributed_percentage: Option<f64>,
pub distributed_wallets: Option<i32>,
pub ticker: Option<String>,
pub total_bundles: Option<i32>,
pub total_holding_amount: Option<i64>,
pub total_holding_percentage: Option<f64>,
pub total_percentage_bundled: Option<f64>,
pub total_sol_spent: Option<f64>,
pub total_tokens_bundled: Option<i64>,
}Expand description
Main bundle response from TrenchBot
Fields
bonded: Option<bool>Indicates if the bundle is bonded
bundles: Option<HashMap<String, BundleDetails>>Collection of bundles, keyed by bundle ID
creator_analysis: Option<CreatorAnalysis>Analysis of the bundle creator
distributed_amount: Option<i64>Total amount of tokens distributed
distributed_percentage: Option<f64>Percentage of total tokens distributed
distributed_wallets: Option<i32>Number of wallets the token has been distributed to
ticker: Option<String>Ticker symbol of the token
total_bundles: Option<i32>Total number of bundles created for this token
total_holding_amount: Option<i64>Total amount of tokens held in bundles
total_holding_percentage: Option<f64>Percentage of the total token supply held in bundles
total_percentage_bundled: Option<f64>Total percentage of tokens that are bundled
total_sol_spent: Option<f64>Total SOL spent on creating the bundles
total_tokens_bundled: Option<i64>Total number of tokens included in bundles