pub struct WalletInfo {
pub sol: Option<f64>,
pub sol_percentage: Option<f64>,
pub token_percentage: Option<f64>,
pub tokens: Option<i64>,
}Expand description
Information about a specific wallet’s interaction with a bundle
Fields
sol: Option<f64>SOL balance of the wallet associated with this bundle
sol_percentage: Option<f64>Percentage of total SOL in the bundle represented by this wallet
token_percentage: Option<f64>Percentage of total tokens in the bundle held by this wallet
tokens: Option<i64>Number of tokens held by this wallet within the bundle